HugoBuildContextX extension

on

Properties

colorScheme ColorScheme

Available on BuildContext, provided by the HugoBuildContextX extension

Returns the colorScheme of the current context, shorthand for Theme.of(context).colorScheme
no setter
height double

Available on BuildContext, provided by the HugoBuildContextX extension

Returns the height of the current context, shorthand for MediaQuery.of(context).size.height
no setter
primaryColor Color

Available on BuildContext, provided by the HugoBuildContextX extension

Returns the primary color of the current context, shorthand for Theme.of(context).colorScheme.primary
no setter
secondaryColor Color

Available on BuildContext, provided by the HugoBuildContextX extension

Returns the secondary color of the current context, shorthand for Theme.of(context).colorScheme.secondary
no setter
textTheme TextTheme

Available on BuildContext, provided by the HugoBuildContextX extension

Returns the textTheme of the current context, shorthand for Theme.of(context).textTheme
no setter
width double

Available on BuildContext, provided by the HugoBuildContextX extension

Returns the width of the current context, shorthand for MediaQuery.of(context).size.width
no setter