height property
double
get
height
Returns the height of the current context, shorthand for MediaQuery.of(context).size.height
Implementation
double get height => MediaQuery.of(this).size.height;
Returns the height of the current context, shorthand for MediaQuery.of(context).size.height
double get height => MediaQuery.of(this).size.height;