width property
double
get
width
Returns the width of the current context, shorthand for MediaQuery.of(context).size.width
Implementation
double get width => MediaQuery.of(this).size.width;
Returns the width of the current context, shorthand for MediaQuery.of(context).size.width
double get width => MediaQuery.of(this).size.width;