HugoBuildContextX extension
- on
Properties
- colorScheme → ColorScheme
-
Available on BuildContext, provided by the HugoBuildContextX extension
Returns the colorScheme of the current context, shorthand for Theme.of(context).colorSchemeno setter - height → double
-
Available on BuildContext, provided by the HugoBuildContextX extension
Returns the height of the current context, shorthand for MediaQuery.of(context).size.heightno setter - primaryColor → Color
-
Available on BuildContext, provided by the HugoBuildContextX extension
Returns the primary color of the current context, shorthand for Theme.of(context).colorScheme.primaryno setter - secondaryColor → Color
-
Available on BuildContext, provided by the HugoBuildContextX extension
Returns the secondary color of the current context, shorthand for Theme.of(context).colorScheme.secondaryno setter - textTheme → TextTheme
-
Available on BuildContext, provided by the HugoBuildContextX extension
Returns the textTheme of the current context, shorthand for Theme.of(context).textThemeno setter - width → double
-
Available on BuildContext, provided by the HugoBuildContextX extension
Returns the width of the current context, shorthand for MediaQuery.of(context).size.widthno setter